class AttributeField
  
  include Mongoid::Document
  include Mongoid::Timestamps
  
  field :key
  field :markup
  field :locale, :type => Boolean
  field :list_options, :type => Array
  field :built_in, :type => Boolean, :default => false
  field :disabled, :type => Boolean, :default => false
  
  embedded_in :attribute
  has_one :i18n_variable, :as => :language_value, :autosave => true, :dependent => :destroy
  has_many :attribute_values
  validates_uniqueness_of :key
  accepts_nested_attributes_for :i18n_variable, :allow_destroy => true
  
  # Convert the string list_options into an array
  def select_list_options=(var)
    self.list_options = var.gsub(' ', '').split(',')
  end
  
  # Convert the array list_options into a string
  def select_list_options
    self.list_options.to_a.join(', ')
  end
  
  def is_built_in?
    self.built_in
  end
  
  def is_disabled?
    self.disabled
  end

end
